@@ -7,6 +7,7 @@ import (
 	"os"
 	"os/exec"
 	"path"
+	"strings"
 )
 
 //go:embed default/*.toml
@@ -23,6 +24,7 @@ type Config struct {
 	OpLog     OpLogConfig       `toml:"oplog"`
 	Graph     GraphConfig       `toml:"graph"`
 	Limit     int               `toml:"limit"`
+	Git       GitConfig         `toml:"git"`
 }
 
 type Color struct {
@@ -133,16 +135,37 @@ type RevisionsConfig struct {
 	Revset      string `toml:"revset"`
 }
 
+type PreviewPosition int
+
+const (
+	PreviewPositionAuto PreviewPosition = iota
+	PreviewPositionBottom
+	PreviewPositionRight
+)
+
 type PreviewConfig struct {
 	RevisionCommand          []string `toml:"revision_command"`
 	OplogCommand             []string `toml:"oplog_command"`
 	FileCommand              []string `toml:"file_command"`
 	ShowAtStart              bool     `toml:"show_at_start"`
-	ShowAtBottom             bool     `toml:"show_at_bottom"`
+	Position                 string   `toml:"position"`
 	WidthPercentage          float64  `toml:"width_percentage"`
 	WidthIncrementPercentage float64  `toml:"width_increment_percentage"`
 }
 
+func GetPreviewPosition(c *Config) (PreviewPosition, error) {
+	switch value := c.Preview.Position; value {
+	case "auto":
+		return PreviewPositionAuto, nil
+	case "bottom":
+		return PreviewPositionBottom, nil
+	case "right":
+		return PreviewPositionRight, nil
+	default:
+		return PreviewPositionAuto, fmt.Errorf("invalid value for 'preview.position': %q (expected one of: auto, bottom, right)", value)
+	}
+}
+
 type OpLogConfig struct {
 	Limit int `toml:"limit"`
 }
@@ -252,3 +275,15 @@ func GetSuggestExecMode(c *Config) (SuggestMode, error) {
 		return SuggestModeOff, fmt.Errorf("invalid value for 'suggest.exec.mode': %q (expected one of: off, fuzzy, regex)", value)
 	}
 }
+
+type GitConfig struct {
+	DefaultRemote string `toml:"default_remote"`
+}
+
+func GetGitDefaultRemote(c *Config) string {
+	remote := c.Git.DefaultRemote
+	if strings.TrimSpace(remote) == "" {
+		return "origin"
+	}
+	return remote
+}
