@@ -24,12 +24,14 @@ func Convert(m KeyMappings[keys]) KeyMappings[key.Binding] {
 		Diff:              key.NewBinding(key.WithKeys(m.Diff...), key.WithHelp(JoinKeys(m.Diff), "diff")),
 		Describe:          key.NewBinding(key.WithKeys(m.Describe...), key.WithHelp(JoinKeys(m.Describe), "describe")),
 		Undo:              key.NewBinding(key.WithKeys(m.Undo...), key.WithHelp(JoinKeys(m.Undo), "undo")),
+		Redo:              key.NewBinding(key.WithKeys(m.Redo...), key.WithHelp(JoinKeys(m.Redo), "redo")),
 		Abandon:           key.NewBinding(key.WithKeys(m.Abandon...), key.WithHelp(JoinKeys(m.Abandon), "abandon")),
 		Edit:              key.NewBinding(key.WithKeys(m.Edit...), key.WithHelp(JoinKeys(m.Edit), "edit")),
 		ForceEdit:         key.NewBinding(key.WithKeys(m.ForceEdit...), key.WithHelp(JoinKeys(m.ForceEdit), "force edit")),
 		Diffedit:          key.NewBinding(key.WithKeys(m.Diffedit...), key.WithHelp(JoinKeys(m.Diffedit), "diff edit")),
 		Absorb:            key.NewBinding(key.WithKeys(m.Absorb...), key.WithHelp(JoinKeys(m.Absorb), "absorb")),
 		Split:             key.NewBinding(key.WithKeys(m.Split...), key.WithHelp(JoinKeys(m.Split), "split")),
+		SplitParallel:     key.NewBinding(key.WithKeys(m.SplitParallel...), key.WithHelp(JoinKeys(m.SplitParallel), "split (parallel)")),
 		Help:              key.NewBinding(key.WithKeys(m.Help...), key.WithHelp(JoinKeys(m.Help), "help")),
 		Evolog: evologModeKeys[key.Binding]{
 			Mode:    key.NewBinding(key.WithKeys(m.Evolog.Mode...), key.WithHelp(JoinKeys(m.Evolog.Mode), "evolog")),
@@ -43,25 +45,26 @@ func Convert(m KeyMappings[keys]) KeyMappings[key.Binding] {
 		CustomCommands:   key.NewBinding(key.WithKeys(m.CustomCommands...), key.WithHelp(JoinKeys(m.CustomCommands), "custom commands menu")),
 		Leader:           key.NewBinding(key.WithKeys(m.Leader...), key.WithHelp(JoinKeys(m.Leader), "leader")),
 		Suspend:          key.NewBinding(key.WithKeys(m.Suspend...), key.WithHelp(JoinKeys(m.Suspend), "suspend")),
-		Megamerge:        key.NewBinding(key.WithKeys(m.Megamerge...), key.WithHelp(JoinKeys(m.Megamerge), "megamerge")),
+		SetParents:       key.NewBinding(key.WithKeys(m.SetParents...), key.WithHelp(JoinKeys(m.SetParents), "set parents")),
 		ExecJJ:           key.NewBinding(key.WithKeys(m.ExecJJ...), key.WithHelp(JoinKeys(m.ExecJJ), "interactive jj")),
 		ExecShell:        key.NewBinding(key.WithKeys(m.ExecShell...), key.WithHelp(JoinKeys(m.ExecShell), "interactive shell command")),
 		Revert: revertModeKeys[key.Binding]{
-			Mode:   key.NewBinding(key.WithKeys(m.Revert.Mode...), key.WithHelp(JoinKeys(m.Revert.Mode), "rebase")),
+			Mode:   key.NewBinding(key.WithKeys(m.Revert.Mode...), key.WithHelp(JoinKeys(m.Revert.Mode), "revert")),
 			After:  key.NewBinding(key.WithKeys(m.Revert.After...), key.WithHelp(JoinKeys(m.Revert.After), "insert after")),
 			Before: key.NewBinding(key.WithKeys(m.Revert.Before...), key.WithHelp(JoinKeys(m.Revert.Before), "insert before")),
 			Onto:   key.NewBinding(key.WithKeys(m.Revert.Onto...), key.WithHelp(JoinKeys(m.Revert.Onto), "onto")),
 			Insert: key.NewBinding(key.WithKeys(m.Revert.Insert...), key.WithHelp(JoinKeys(m.Revert.Insert), "insert between")),
 		},
 		Rebase: rebaseModeKeys[key.Binding]{
-			Mode:     key.NewBinding(key.WithKeys(m.Rebase.Mode...), key.WithHelp(JoinKeys(m.Rebase.Mode), "rebase")),
-			Revision: key.NewBinding(key.WithKeys(m.Rebase.Revision...), key.WithHelp(JoinKeys(m.Rebase.Revision), "revision")),
-			Source:   key.NewBinding(key.WithKeys(m.Rebase.Source...), key.WithHelp(JoinKeys(m.Rebase.Source), "source")),
-			Branch:   key.NewBinding(key.WithKeys(m.Rebase.Branch...), key.WithHelp(JoinKeys(m.Rebase.Branch), "branch")),
-			After:    key.NewBinding(key.WithKeys(m.Rebase.After...), key.WithHelp(JoinKeys(m.Rebase.After), "insert after")),
-			Before:   key.NewBinding(key.WithKeys(m.Rebase.Before...), key.WithHelp(JoinKeys(m.Rebase.Before), "insert before")),
-			Onto:     key.NewBinding(key.WithKeys(m.Rebase.Onto...), key.WithHelp(JoinKeys(m.Rebase.Onto), "onto")),
-			Insert:   key.NewBinding(key.WithKeys(m.Rebase.Insert...), key.WithHelp(JoinKeys(m.Rebase.Insert), "insert between")),
+			Mode:        key.NewBinding(key.WithKeys(m.Rebase.Mode...), key.WithHelp(JoinKeys(m.Rebase.Mode), "rebase")),
+			Revision:    key.NewBinding(key.WithKeys(m.Rebase.Revision...), key.WithHelp(JoinKeys(m.Rebase.Revision), "revision")),
+			Source:      key.NewBinding(key.WithKeys(m.Rebase.Source...), key.WithHelp(JoinKeys(m.Rebase.Source), "source")),
+			Branch:      key.NewBinding(key.WithKeys(m.Rebase.Branch...), key.WithHelp(JoinKeys(m.Rebase.Branch), "branch")),
+			After:       key.NewBinding(key.WithKeys(m.Rebase.After...), key.WithHelp(JoinKeys(m.Rebase.After), "insert after")),
+			Before:      key.NewBinding(key.WithKeys(m.Rebase.Before...), key.WithHelp(JoinKeys(m.Rebase.Before), "insert before")),
+			Onto:        key.NewBinding(key.WithKeys(m.Rebase.Onto...), key.WithHelp(JoinKeys(m.Rebase.Onto), "onto")),
+			Insert:      key.NewBinding(key.WithKeys(m.Rebase.Insert...), key.WithHelp(JoinKeys(m.Rebase.Insert), "insert between")),
+			SkipEmptied: key.NewBinding(key.WithKeys(m.Rebase.SkipEmptied...), key.WithHelp(JoinKeys(m.Rebase.SkipEmptied), "skip emptied")),
 		},
 		Duplicate: duplicateModeKeys[key.Binding]{
 			Mode:   key.NewBinding(key.WithKeys(m.Duplicate.Mode...), key.WithHelp(JoinKeys(m.Duplicate.Mode), "duplicate")),
@@ -78,6 +81,7 @@ func Convert(m KeyMappings[keys]) KeyMappings[key.Binding] {
 			Mode:                  key.NewBinding(key.WithKeys(m.Details.Mode...), key.WithHelp(JoinKeys(m.Details.Mode), "details")),
 			Close:                 key.NewBinding(key.WithKeys(m.Details.Close...), key.WithHelp(JoinKeys(m.Details.Close), "close")),
 			Split:                 key.NewBinding(key.WithKeys(m.Details.Split...), key.WithHelp(JoinKeys(m.Details.Split), "split")),
+			SplitParallel:         key.NewBinding(key.WithKeys(m.Details.SplitParallel...), key.WithHelp(JoinKeys(m.Details.SplitParallel), "split (parallel)")),
 			Squash:                key.NewBinding(key.WithKeys(m.Details.Squash...), key.WithHelp(JoinKeys(m.Details.Squash), "squash")),
 			Restore:               key.NewBinding(key.WithKeys(m.Details.Restore...), key.WithHelp(JoinKeys(m.Details.Restore), "restore")),
 			Absorb:                key.NewBinding(key.WithKeys(m.Details.Absorb...), key.WithHelp(JoinKeys(m.Details.Absorb), "absorb")),
@@ -116,6 +120,7 @@ func Convert(m KeyMappings[keys]) KeyMappings[key.Binding] {
 		InlineDescribe: inlineDescribeModeKeys[key.Binding]{
 			Mode:   key.NewBinding(key.WithKeys(m.InlineDescribe.Mode...), key.WithHelp(JoinKeys(m.InlineDescribe.Mode), "inline describe")),
 			Accept: key.NewBinding(key.WithKeys(m.InlineDescribe.Accept...), key.WithHelp(JoinKeys(m.InlineDescribe.Accept), "accept")),
+			Editor: key.NewBinding(key.WithKeys(m.InlineDescribe.Editor...), key.WithHelp(JoinKeys(m.InlineDescribe.Editor), "open in editor")),
 		},
 		FileSearch: fileSearchKeys[key.Binding]{
 			Toggle: key.NewBinding(key.WithKeys(m.FileSearch.Toggle...), key.WithHelp(JoinKeys(m.FileSearch.Toggle), "fuzzy files search")),
@@ -173,7 +178,9 @@ type KeyMappings[T any] struct {
 	Diffedit          T                         `toml:"diffedit"`
 	Absorb            T                         `toml:"absorb"`
 	Split             T                         `toml:"split"`
+	SplitParallel     T                         `toml:"split_parallel"`
 	Undo              T                         `toml:"undo"`
+	Redo              T                         `toml:"redo"`
 	Revset            T                         `toml:"revset"`
 	ExecJJ            T                         `toml:"exec_jj"`
 	ExecShell         T                         `toml:"exec_shell"`
@@ -183,7 +190,7 @@ type KeyMappings[T any] struct {
 	CustomCommands    T                         `toml:"custom_commands"`
 	Leader            T                         `toml:"leader"`
 	Suspend           T                         `toml:"suspend"`
-	Megamerge         T                         `toml:"megamerge"`
+	SetParents        T                         `toml:"set_parents"`
 	Revert            revertModeKeys[T]         `toml:"revert"`
 	Rebase            rebaseModeKeys[T]         `toml:"rebase"`
 	Duplicate         duplicateModeKeys[T]      `toml:"duplicate"`
@@ -223,14 +230,15 @@ type revertModeKeys[T any] struct {
 }
 
 type rebaseModeKeys[T any] struct {
-	Mode     T `toml:"mode"`
-	Revision T `toml:"revision"`
-	Source   T `toml:"source"`
-	Branch   T `toml:"branch"`
-	After    T `toml:"after"`
-	Before   T `toml:"before"`
-	Onto     T `toml:"onto"`
-	Insert   T `toml:"insert"`
+	Mode        T `toml:"mode"`
+	Revision    T `toml:"revision"`
+	Source      T `toml:"source"`
+	Branch      T `toml:"branch"`
+	After       T `toml:"after"`
+	Before      T `toml:"before"`
+	Onto        T `toml:"onto"`
+	Insert      T `toml:"insert"`
+	SkipEmptied T `toml:"skip_emptied"`
 }
 
 type duplicateModeKeys[T any] struct {
@@ -250,6 +258,7 @@ type detailsModeKeys[T any] struct {
 	Mode                  T `toml:"mode"`
 	Close                 T `toml:"close"`
 	Split                 T `toml:"split"`
+	SplitParallel         T `toml:"split_parallel"`
 	Restore               T `toml:"restore"`
 	Absorb                T `toml:"absorb"`
 	Squash                T `toml:"squash"`
@@ -283,6 +292,7 @@ type opLogModeKeys[T any] struct {
 type inlineDescribeModeKeys[T any] struct {
 	Mode   T `toml:"mode"`
 	Accept T `toml:"accept"`
+	Editor T `toml:"editor"`
 }
 
 type fileSearchKeys[T any] struct {
