@@ -69,8 +69,11 @@ func DiffEdit(changeId string) CommandArgs {
 	return []string{"diffedit", "-r", changeId}
 }
 
-func Split(revision string, files []string) CommandArgs {
+func Split(revision string, files []string, parallel bool) CommandArgs {
 	args := []string{"split", "-r", revision}
+	if parallel {
+		args = append(args, "--parallel")
+	}
 	var escapedFiles []string
 	for _, file := range files {
 		escapedFiles = append(escapedFiles, EscapeFileName(file))
@@ -89,8 +92,10 @@ func SquashFiles(from string, into string, files []string) CommandArgs {
 	return args
 }
 
-func Describe(revision string) CommandArgs {
-	return []string{"describe", "-r", revision, "--edit"}
+func Describe(revisions SelectedRevisions) CommandArgs {
+	args := []string{"describe", "--edit"}
+	args = append(args, revisions.AsArgs()...)
+	return args
 }
 
 func SetDescription(revision string, description string) CommandArgs {
@@ -131,6 +136,14 @@ func Restore(revision string, files []string) CommandArgs {
 	return args
 }
 
+func RestoreInteractive(revision string, file string) CommandArgs {
+	args := []string{"restore", "-c", revision, "--interactive"}
+	if file != "" {
+		args = append(args, EscapeFileName(file))
+	}
+	return args
+}
+
 func RestoreEvolog(from string, into string) CommandArgs {
 	args := []string{"restore", "--from", from, "--into", into, "--restore-descendants"}
 	return args
@@ -140,6 +153,10 @@ func Undo() CommandArgs {
 	return []string{"undo"}
 }
 
+func Redo() CommandArgs {
+	return []string{"redo"}
+}
+
 func Snapshot() CommandArgs {
 	return []string{"debug", "snapshot"}
 }
@@ -177,7 +194,7 @@ func BookmarkUntrack(name string) CommandArgs {
 	return []string{"bookmark", "untrack", name}
 }
 
-func Squash(from SelectedRevisions, destination string, keepEmptied bool, interactive bool) CommandArgs {
+func Squash(from SelectedRevisions, destination string, files []string, keepEmptied bool, interactive bool, ignoreImmutable bool) CommandArgs {
 	args := []string{"squash"}
 	args = append(args, from.AsPrefixedArgs("--from")...)
 	args = append(args, "--into", destination)
@@ -187,6 +204,16 @@ func Squash(from SelectedRevisions, destination string, keepEmptied bool, intera
 	if interactive {
 		args = append(args, "--interactive")
 	}
+	if ignoreImmutable {
+		args = append(args, "--ignore-immutable")
+	}
+	if len(files) > 0 {
+		var escapedFiles []string
+		for _, file := range files {
+			escapedFiles = append(escapedFiles, EscapeFileName(file))
+		}
+		args = append(args, escapedFiles...)
+	}
 	return args
 }
 
@@ -223,6 +250,10 @@ func GitPush(flags ...string) CommandArgs {
 	return args
 }
 
+func GitRemoteList() CommandArgs {
+	return []string{"git", "remote", "list"}
+}
+
 func Show(revision string, extraArgs ...string) CommandArgs {
 	args := []string{"show", "-r", revision, "--color", "always", "--ignore-working-copy"}
 	if extraArgs != nil {
@@ -231,17 +262,20 @@ func Show(revision string, extraArgs ...string) CommandArgs {
 	return args
 }
 
-func Rebase(from SelectedRevisions, to string, source string, target string, ignoreImmutable bool) CommandArgs {
+func Rebase(from SelectedRevisions, to string, source string, target string, skipEmptied bool, ignoreImmutable bool) CommandArgs {
 	args := []string{"rebase"}
 	args = append(args, from.AsPrefixedArgs(source)...)
 	args = append(args, target, to)
 	if ignoreImmutable {
 		args = append(args, "--ignore-immutable")
 	}
+	if skipEmptied {
+		args = append(args, "--skip-emptied")
+	}
 	return args
 }
 
-func RebaseInsert(from SelectedRevisions, insertAfter string, insertBefore string, ignoreImmutable bool) CommandArgs {
+func RebaseInsert(from SelectedRevisions, insertAfter string, insertBefore string, skipEmptied bool, ignoreImmutable bool) CommandArgs {
 	args := []string{"rebase"}
 	args = append(args, from.AsArgs()...)
 	args = append(args, "--insert-before", insertBefore)
@@ -249,23 +283,25 @@ func RebaseInsert(from SelectedRevisions, insertAfter string, insertBefore strin
 	if ignoreImmutable {
 		args = append(args, "--ignore-immutable")
 	}
+	if skipEmptied {
+		args = append(args, "--skip-emptied")
+	}
 	return args
 }
 
-func ModifyParents(to string, parentsToAdd []string, parentsToRemove []string) CommandArgs {
+func SetParents(to string, parentsToAdd []string, parentsToRemove []string) CommandArgs {
 	var b strings.Builder
 	b.WriteString("parents(")
 	b.WriteString(to)
-	b.WriteString(") ")
+	b.WriteString(")")
 	for _, remove := range parentsToRemove {
 		b.WriteString(" ~ ")
 		b.WriteString(remove)
 	}
-	for _, add := range parentsToAdd {
-		b.WriteString(" | ")
-		b.WriteString(add)
-	}
 	args := []string{"rebase", "-s", to, "-d", b.String()}
+	for _, add := range parentsToAdd {
+		args = append(args, "-d", add)
+	}
 	return args
 }
 
@@ -370,9 +406,11 @@ func GetFirstChild(revision *Commit) CommandArgs {
 }
 
 func FilesInRevision(revision *Commit) CommandArgs {
-	args := []string{"file", "list", "-r", revision.CommitId,
+	args := []string{
+		"file", "list", "-r", revision.CommitId,
 		"--color", "never", "--no-pager", "--quiet", "--ignore-working-copy",
-		"--template", "self.path() ++ \"\n\""}
+		"--template", "self.path() ++ \"\n\"",
+	}
 	return args
 }
 
