@@ -13,26 +13,36 @@ import (
 
 func Test_Push(t *testing.T) {
 	commandRunner := test.NewTestCommandRunner(t)
-	commandRunner.Expect(jj.GitPush())
+	commandRunner.Expect(jj.GitRemoteList()).SetOutput([]byte(""))
+	commandRunner.Expect(jj.GitPush("--remote", ""))
 	defer commandRunner.Verify()
 
-	op := NewModel(test.NewTestContext(commandRunner), nil, 0, 0)
-	tm := teatest.NewTestModel(t, test.NewShell(op))
+	op := NewModel(test.NewTestContext(commandRunner), jj.NewSelectedRevisions(), 0, 0)
+	tm := teatest.NewTestModel(t, op)
 	tm.Send(tea.KeyMsg{Type: tea.KeyEnter})
+	teatest.WaitFor(t, tm.Output(), func(bts []byte) bool {
+		return commandRunner.IsVerified()
+	})
+	tm.Quit()
 	tm.WaitFinished(t, teatest.WithFinalTimeout(3*time.Second))
 }
 
 func Test_Fetch(t *testing.T) {
 	commandRunner := test.NewTestCommandRunner(t)
-	commandRunner.Expect(jj.GitFetch())
+	commandRunner.Expect(jj.GitRemoteList()).SetOutput([]byte(""))
+	commandRunner.Expect(jj.GitFetch("--remote", ""))
 	defer commandRunner.Verify()
 
-	op := NewModel(test.NewTestContext(commandRunner), nil, 0, 0)
-	tm := teatest.NewTestModel(t, test.NewShell(op))
+	op := NewModel(test.NewTestContext(commandRunner), jj.NewSelectedRevisions(), 0, 0)
+	tm := teatest.NewTestModel(t, op)
 	tm.Type("/")
 	tm.Type("fetch")
 	tm.Send(tea.KeyMsg{Type: tea.KeyEnter})
 	tm.Send(tea.KeyMsg{Type: tea.KeyEnter})
+	teatest.WaitFor(t, tm.Output(), func(bts []byte) bool {
+		return commandRunner.IsVerified()
+	})
+	tm.Quit()
 	tm.WaitFinished(t, teatest.WithFinalTimeout(3*time.Second))
 }
 
@@ -57,15 +67,20 @@ func Test_PushChange(t *testing.T) {
 	commandRunner := test.NewTestCommandRunner(t)
 	// Expect bookmark list to be loaded since we have a changeId
 	commandRunner.Expect(jj.BookmarkList(changeId)).SetOutput([]byte(""))
-	commandRunner.Expect(jj.GitPush("--change", changeId))
+	commandRunner.Expect(jj.GitRemoteList()).SetOutput([]byte(""))
+	commandRunner.Expect(jj.GitPush("--change", changeId, "--remote", ""))
 	defer commandRunner.Verify()
 
-	op := NewModel(test.NewTestContext(commandRunner), &jj.Commit{ChangeId: changeId}, 0, 0)
-	tm := teatest.NewTestModel(t, test.NewShell(op))
+	op := NewModel(test.NewTestContext(commandRunner), jj.NewSelectedRevisions(&jj.Commit{ChangeId: changeId}), 0, 0)
+	tm := teatest.NewTestModel(t, op)
 	// Filter for the exact item and ensure selection is at index 0
 	tm.Type("/")
 	tm.Type("git push --change")
 	tm.Send(tea.KeyMsg{Type: tea.KeyDown}) // Ensure first item is selected
 	tm.Send(tea.KeyMsg{Type: tea.KeyEnter})
+	teatest.WaitFor(t, tm.Output(), func(bts []byte) bool {
+		return commandRunner.IsVerified()
+	})
+	tm.Quit()
 	tm.WaitFinished(t, teatest.WithFinalTimeout(3*time.Second))
 }
