@@ -19,7 +19,9 @@ func Test_Accept(t *testing.T) {
 	commandRunner.Expect(jj.Abandon(revisions, false))
 	defer commandRunner.Verify()
 
-	model := test.NewOperationHost(NewOperation(test.NewTestContext(commandRunner), revisions), commit)
+	model := NewOperation(test.NewTestContext(commandRunner), revisions)
+	model.SetSelectedRevision(commit)
+
 	tm := teatest.NewTestModel(t, model)
 	teatest.WaitFor(t, tm.Output(), func(bts []byte) bool {
 		return bytes.Contains(bts, []byte("abandon"))
@@ -27,8 +29,9 @@ func Test_Accept(t *testing.T) {
 
 	tm.Send(tea.KeyMsg{Type: tea.KeyEnter})
 	teatest.WaitFor(t, tm.Output(), func(bts []byte) bool {
-		return bytes.Contains(bts, []byte("closed"))
+		return commandRunner.IsVerified()
 	})
+	tm.Quit()
 	tm.WaitFinished(t, teatest.WithFinalTimeout(3*time.Second))
 }
 
@@ -36,11 +39,14 @@ func Test_Cancel(t *testing.T) {
 	commandRunner := test.NewTestCommandRunner(t)
 	defer commandRunner.Verify()
 
-	model := test.NewOperationHost(NewOperation(test.NewTestContext(commandRunner), revisions), commit)
+	model := NewOperation(test.NewTestContext(commandRunner), revisions)
+	model.SetSelectedRevision(commit)
+
 	tm := teatest.NewTestModel(t, model)
 	tm.Send(tea.KeyMsg{Type: tea.KeyEsc})
 	teatest.WaitFor(t, tm.Output(), func(bts []byte) bool {
-		return bytes.Contains(bts, []byte("closed"))
+		return commandRunner.IsVerified()
 	})
+	tm.Quit()
 	tm.WaitFinished(t, teatest.WithFinalTimeout(3*time.Second))
 }
