@@ -7,11 +7,13 @@ import (
 	"reflect"
 	"slices"
 	"strings"
+	"sync/atomic"
 
-	"github.com/idursun/jjui/internal/ui/ace_jump"
+	"github.com/idursun/jjui/internal/ui/common/list"
+	"github.com/idursun/jjui/internal/ui/operations/ace_jump"
 	"github.com/idursun/jjui/internal/ui/operations/duplicate"
-	"github.com/idursun/jjui/internal/ui/operations/megamerge"
 	"github.com/idursun/jjui/internal/ui/operations/revert"
+	"github.com/idursun/jjui/internal/ui/operations/set_parents"
 
 	"github.com/idursun/jjui/internal/parser"
 	"github.com/idursun/jjui/internal/ui/operations/describe"
@@ -34,29 +36,92 @@ import (
 	"github.com/idursun/jjui/internal/ui/operations/squash"
 )
 
+var _ list.IList = (*Model)(nil)
+var _ list.IListCursor = (*Model)(nil)
+var _ common.Focusable = (*Model)(nil)
+var _ common.Editable = (*Model)(nil)
+
+var pageDownKey = key.NewBinding(key.WithKeys("pgdown"))
+var pageUpKey = key.NewBinding(key.WithKeys("pgup"))
+
 type Model struct {
+	*common.Sizeable
 	rows             []parser.Row
-	tag              uint64
+	tag              atomic.Uint64
 	revisionToSelect string
 	offScreenRows    []parser.Row
 	streamer         *graph.GraphStreamer
-	rowsChan         <-chan parser.RowBatch
-	controlChan      chan parser.ControlMsg
 	hasMore          bool
-	op               operations.Operation
+	op               tea.Model
 	cursor           int
-	width            int
-	height           int
 	context          *appContext.MainContext
 	keymap           config.KeyMappings[key.Binding]
 	output           string
 	err              error
-	aceJump          *ace_jump.AceJump
 	quickSearch      string
 	previousOpLogId  string
 	isLoading        bool
-	w                *graph.Renderer
+	renderer         *revisionListRenderer
 	textStyle        lipgloss.Style
+	dimmedStyle      lipgloss.Style
+	selectedStyle    lipgloss.Style
+}
+
+func (m *Model) Cursor() int {
+	return m.cursor
+}
+
+func (m *Model) SetCursor(index int) {
+	if index >= 0 && index < len(m.rows) {
+		m.cursor = index
+	}
+}
+
+func (m *Model) Len() int {
+	return len(m.rows)
+}
+
+func (m *Model) GetItemRenderer(index int) list.IItemRenderer {
+	var (
+		before, after, renderOverDescription, beforeCommitId, beforeChangeId string
+	)
+	row := m.rows[index]
+	inLane := m.renderer.tracer.IsInSameLane(index)
+	isHighlighted := index == m.cursor
+
+	if op, ok := m.op.(operations.Operation); ok {
+		before = op.Render(row.Commit, operations.RenderPositionBefore)
+		after = op.Render(row.Commit, operations.RenderPositionAfter)
+		renderOverDescription = ""
+		if isHighlighted {
+			renderOverDescription = op.Render(row.Commit, operations.RenderOverDescription)
+		}
+		beforeCommitId = op.Render(row.Commit, operations.RenderBeforeCommitId)
+		beforeChangeId = op.Render(row.Commit, operations.RenderBeforeChangeId)
+	}
+
+	return &itemRenderer{
+		row:            row,
+		before:         before,
+		after:          after,
+		description:    renderOverDescription,
+		beforeChangeId: beforeChangeId,
+		beforeCommitId: beforeCommitId,
+		isHighlighted:  isHighlighted,
+		SearchText:     m.quickSearch,
+		textStyle:      m.textStyle,
+		dimmedStyle:    m.dimmedStyle,
+		selectedStyle:  m.selectedStyle,
+		isChecked:      m.renderer.selections[row.Commit.GetChangeId()],
+		isGutterInLane: func(lineIndex, segmentIndex int) bool {
+			return m.renderer.tracer.IsGutterInLane(index, lineIndex, segmentIndex)
+		},
+		updateGutterText: func(lineIndex, segmentIndex int, text string) string {
+			return m.renderer.tracer.UpdateGutterText(index, lineIndex, segmentIndex, text)
+		},
+		inLane: inLane,
+		op:     m.op.(operations.Operation),
+	}
 }
 
 type revisionsMsg struct {
@@ -86,9 +151,16 @@ type appendRowsBatchMsg struct {
 	tag     uint64
 }
 
+func (m *Model) IsEditing() bool {
+	if f, ok := m.op.(common.Editable); ok {
+		return f.IsEditing()
+	}
+	return false
+}
+
 func (m *Model) IsFocused() bool {
-	if _, ok := m.op.(common.Focusable); ok {
-		return true
+	if f, ok := m.op.(common.Focusable); ok {
+		return f.IsFocused()
 	}
 	return false
 }
@@ -100,22 +172,6 @@ func (m *Model) InNormalMode() bool {
 	return false
 }
 
-func (m *Model) Width() int {
-	return m.width
-}
-
-func (m *Model) Height() int {
-	return m.height
-}
-
-func (m *Model) SetWidth(w int) {
-	m.width = w
-}
-
-func (m *Model) SetHeight(h int) {
-	m.height = h
-}
-
 func (m *Model) ShortHelp() []key.Binding {
 	if op, ok := m.op.(help.KeyMap); ok {
 		return op.ShortHelp()
@@ -165,17 +221,29 @@ func (m *Model) Update(msg tea.Msg) (*Model, tea.Cmd) {
 	if k, ok := msg.(revisionsMsg); ok {
 		msg = k.msg
 	}
+	var cmd tea.Cmd
+	var nm *Model
+	nm, cmd = m.internalUpdate(msg)
+
+	if curSelected := m.SelectedRevision(); curSelected != nil {
+		if op, ok := m.op.(operations.TracksSelectedRevision); ok {
+			op.SetSelectedRevision(curSelected)
+		}
+	}
+
+	return nm, cmd
+}
+
+func (m *Model) internalUpdate(msg tea.Msg) (*Model, tea.Cmd) {
 	switch msg := msg.(type) {
 	case common.CloseViewMsg:
 		m.op = operations.NewDefault()
 		return m, m.updateSelection()
-	case common.UpdateRevSetMsg:
-		return m, common.Refresh
 	case common.QuickSearchMsg:
 		m.quickSearch = string(msg)
 		m.cursor = m.search(0)
 		m.op = operations.NewDefault()
-		m.w.ResetViewRange()
+		m.renderer.Reset()
 		return m, nil
 	case common.CommandCompletedMsg:
 		m.output = msg.Output
@@ -194,10 +262,11 @@ func (m *Model) Update(msg tea.Msg) (*Model, tea.Cmd) {
 			m.context.ClearCheckedItems(reflect.TypeFor[appContext.SelectedRevision]())
 		}
 		m.isLoading = true
-		cmd, _ := m.updateOperation(msg)
+		var cmd tea.Cmd
+		m.op, cmd = m.op.Update(msg)
 		if config.Current.Revisions.LogBatching {
-			m.tag += 1
-			return m, tea.Batch(m.loadStreaming(m.context.CurrentRevset, msg.SelectedRevision, m.tag), cmd)
+			currentTag := m.tag.Add(1)
+			return m, tea.Batch(m.loadStreaming(m.context.CurrentRevset, msg.SelectedRevision, currentTag), cmd)
 		} else {
 			return m, tea.Batch(m.load(m.context.CurrentRevset, msg.SelectedRevision), cmd)
 		}
@@ -223,7 +292,7 @@ func (m *Model) Update(msg tea.Msg) (*Model, tea.Cmd) {
 		log.Println("Starting streaming revisions message received with tag:", msg.tag, "revision to select:", msg.selectedRevision)
 		return m, m.requestMoreRows(msg.tag)
 	case appendRowsBatchMsg:
-		if msg.tag != m.tag {
+		if msg.tag != m.tag.Load() {
 			return m, nil
 		}
 		m.offScreenRows = append(m.offScreenRows, msg.rows...)
@@ -232,7 +301,7 @@ func (m *Model) Update(msg tea.Msg) (*Model, tea.Cmd) {
 
 		if m.hasMore {
 			// keep requesting rows until we reach the initial load count or the current cursor position
-			if len(m.offScreenRows) < m.cursor+1 || len(m.offScreenRows) < m.w.LastRowIndex()+1 {
+			if len(m.offScreenRows) < m.cursor+1 || len(m.offScreenRows) < m.renderer.ViewRange.LastRowIndex+1 {
 				return m, m.requestMoreRows(msg.tag)
 			}
 		} else if m.streamer != nil {
@@ -261,26 +330,23 @@ func (m *Model) Update(msg tea.Msg) (*Model, tea.Cmd) {
 			})
 		}
 		return m, tea.Batch(cmds...)
-	case common.JumpToParentMsg:
-		if msg.Commit == nil {
-			return m, nil
-		}
-		m.jumpToParent(jj.NewSelectedRevisions(msg.Commit))
-		return m, m.updateSelection()
-	}
-
-	// TODO: This is duplicated at the end of the function, needs refactoring
-	if curSelected := m.SelectedRevision(); curSelected != nil {
-		if op, ok := m.op.(operations.TracksSelectedRevision); ok {
-			op.SetSelectedRevision(curSelected)
-		}
+	case common.StartSquashOperationMsg:
+		return m.startSquash(jj.NewSelectedRevisions(msg.Revision), msg.Files)
 	}
 
 	if len(m.rows) == 0 {
 		return m, nil
 	}
 
-	if cmd, ok := m.updateOperation(msg); ok {
+	if op, ok := m.op.(common.Editable); ok && op.IsEditing() {
+		var cmd tea.Cmd
+		m.op, cmd = m.op.Update(msg)
+		return m, cmd
+	}
+
+	if op, ok := m.op.(common.Overlay); ok && op.IsOverlay() {
+		var cmd tea.Cmd
+		m.op, cmd = m.op.Update(msg)
 		return m, cmd
 	}
 
@@ -288,24 +354,36 @@ func (m *Model) Update(msg tea.Msg) (*Model, tea.Cmd) {
 	switch msg := msg.(type) {
 	case tea.KeyMsg:
 		switch {
-		case key.Matches(msg, m.keymap.Up):
-			if m.cursor > 0 {
-				m.cursor--
+		case key.Matches(msg, m.keymap.Up, pageUpKey):
+			amount := 1
+			if key.Matches(msg, pageUpKey) && m.renderer.LastRowIndex > m.renderer.FirstRowIndex {
+				amount = m.renderer.LastRowIndex - m.renderer.FirstRowIndex - 1
 			}
-		case key.Matches(msg, m.keymap.Down):
-			if m.cursor < len(m.rows)-1 {
-				m.cursor++
+			if m.cursor-amount >= 0 {
+				m.cursor = m.cursor - amount
+			}
+			return m, m.updateSelection()
+		case key.Matches(msg, m.keymap.Down, pageDownKey):
+			amount := 1
+			if key.Matches(msg, pageDownKey) && m.renderer.LastRowIndex > m.renderer.FirstRowIndex {
+				amount = m.renderer.LastRowIndex - m.renderer.FirstRowIndex - 1
+			}
+			if m.cursor < len(m.rows)-amount {
+				m.cursor = m.cursor + amount
 			} else if m.hasMore {
-				return m, m.requestMoreRows(m.tag)
+				return m, m.requestMoreRows(m.tag.Load())
 			}
+			return m, m.updateSelection()
 		case key.Matches(msg, m.keymap.JumpToParent):
 			m.jumpToParent(m.SelectedRevisions())
+			return m, m.updateSelection()
 		case key.Matches(msg, m.keymap.JumpToChildren):
 			immediate, _ := m.context.RunCommandImmediate(jj.GetFirstChild(m.SelectedRevision()))
 			index := m.selectRevision(string(immediate))
 			if index != -1 {
 				m.cursor = index
 			}
+			return m, m.updateSelection()
 		case key.Matches(msg, m.keymap.JumpToWorkingCopy):
 			workingCopyIndex := m.selectRevision("@")
 			if workingCopyIndex != -1 {
@@ -313,11 +391,15 @@ func (m *Model) Update(msg tea.Msg) (*Model, tea.Cmd) {
 			}
 			return m, m.updateSelection()
 		case key.Matches(msg, m.keymap.AceJump):
-			m.aceJump = m.findAceKeys()
+			op := ace_jump.NewOperation(m, func(index int) parser.Row {
+				return m.rows[index]
+			}, m.renderer.FirstRowIndex, m.renderer.LastRowIndex)
+			m.op = op
+			return m, op.Init()
 		default:
-			if op, ok := m.op.(operations.HandleKey); ok {
-				cmd = op.HandleKey(msg)
-				break
+			if op, ok := m.op.(common.Focusable); ok && op.IsFocused() {
+				m.op, cmd = m.op.Update(msg)
+				return m, cmd
 			}
 
 			switch {
@@ -335,39 +417,44 @@ func (m *Model) Update(msg tea.Msg) (*Model, tea.Cmd) {
 				m.op = operations.NewDefault()
 			case key.Matches(msg, m.keymap.QuickSearchCycle):
 				m.cursor = m.search(m.cursor + 1)
-				m.w.ResetViewRange()
+				m.renderer.Reset()
 				return m, nil
 			case key.Matches(msg, m.keymap.Details.Mode):
-				m.op, cmd = details.NewOperation(m.context, m.SelectedRevision())
+				m.op = details.NewOperation(m.context, m.SelectedRevision(), m.Height)
+				return m, m.op.Init()
 			case key.Matches(msg, m.keymap.InlineDescribe.Mode):
-				m.op, cmd = describe.NewOperation(m.context, m.SelectedRevision().GetChangeId(), m.width)
-				return m, cmd
+				m.op = describe.NewOperation(m.context, m.SelectedRevision().GetChangeId(), m.Width)
+				return m, m.op.Init()
 			case key.Matches(msg, m.keymap.New):
-				cmd = m.context.RunCommand(jj.New(m.SelectedRevisions()), common.RefreshAndSelect("@"))
+				return m, m.context.RunCommand(jj.New(m.SelectedRevisions()), common.RefreshAndSelect("@"))
 			case key.Matches(msg, m.keymap.Commit):
-				cmd = m.context.RunInteractiveCommand(jj.CommitWorkingCopy(), common.Refresh)
+				return m, m.context.RunInteractiveCommand(jj.CommitWorkingCopy(), common.Refresh)
 			case key.Matches(msg, m.keymap.Edit, m.keymap.ForceEdit):
 				ignoreImmutable := key.Matches(msg, m.keymap.ForceEdit)
-				cmd = m.context.RunCommand(jj.Edit(m.SelectedRevision().GetChangeId(), ignoreImmutable), common.Refresh)
+				return m, m.context.RunCommand(jj.Edit(m.SelectedRevision().GetChangeId(), ignoreImmutable), common.Refresh)
 			case key.Matches(msg, m.keymap.Diffedit):
 				changeId := m.SelectedRevision().GetChangeId()
-				cmd = m.context.RunInteractiveCommand(jj.DiffEdit(changeId), common.Refresh)
+				return m, m.context.RunInteractiveCommand(jj.DiffEdit(changeId), common.Refresh)
 			case key.Matches(msg, m.keymap.Absorb):
 				changeId := m.SelectedRevision().GetChangeId()
-				cmd = m.context.RunCommand(jj.Absorb(changeId), common.Refresh)
+				return m, m.context.RunCommand(jj.Absorb(changeId), common.Refresh)
 			case key.Matches(msg, m.keymap.Abandon):
 				selections := m.SelectedRevisions()
 				m.op = abandon.NewOperation(m.context, selections)
+				return m, m.op.Init()
 			case key.Matches(msg, m.keymap.Bookmark.Set):
-				m.op, cmd = bookmark.NewSetBookmarkOperation(m.context, m.SelectedRevision().GetChangeId())
-			case key.Matches(msg, m.keymap.Split):
+				m.op = bookmark.NewSetBookmarkOperation(m.context, m.SelectedRevision().GetChangeId())
+				return m, m.op.Init()
+			case key.Matches(msg, m.keymap.Split, m.keymap.SplitParallel):
+				isParallel := key.Matches(msg, m.keymap.SplitParallel)
 				currentRevision := m.SelectedRevision().GetChangeId()
-				return m, m.context.RunInteractiveCommand(jj.Split(currentRevision, []string{}), common.Refresh)
+				return m, m.context.RunInteractiveCommand(jj.Split(currentRevision, []string{}, isParallel), common.Refresh)
 			case key.Matches(msg, m.keymap.Describe):
-				currentRevision := m.SelectedRevision().GetChangeId()
-				return m, m.context.RunInteractiveCommand(jj.Describe(currentRevision), common.Refresh)
+				selections := m.SelectedRevisions()
+				return m, m.context.RunInteractiveCommand(jj.Describe(selections), common.Refresh)
 			case key.Matches(msg, m.keymap.Evolog.Mode):
-				m.op, cmd = evolog.NewOperation(m.context, m.SelectedRevision(), m.width, m.height)
+				m.op = evolog.NewOperation(m.context, m.SelectedRevision(), m.Width, m.Height)
+				return m, m.op.Init()
 			case key.Matches(msg, m.keymap.Diff):
 				return m, func() tea.Msg {
 					changeId := m.SelectedRevision().GetChangeId()
@@ -375,38 +462,40 @@ func (m *Model) Update(msg tea.Msg) (*Model, tea.Cmd) {
 					return common.ShowDiffMsg(output)
 				}
 			case key.Matches(msg, m.keymap.Refresh):
-				cmd = common.Refresh
+				return m, common.Refresh
 			case key.Matches(msg, m.keymap.Squash.Mode):
-				selectedRevisions := m.SelectedRevisions()
-				parent, _ := m.context.RunCommandImmediate(jj.GetParent(selectedRevisions))
-				parentIdx := m.selectRevision(string(parent))
-				if parentIdx != -1 {
-					m.cursor = parentIdx
-				} else if m.cursor < len(m.rows)-1 {
-					m.cursor++
-				}
-				m.op = squash.NewOperation(m.context, selectedRevisions)
+				return m.startSquash(m.SelectedRevisions(), nil)
 			case key.Matches(msg, m.keymap.Revert.Mode):
 				m.op = revert.NewOperation(m.context, m.SelectedRevisions(), revert.TargetDestination)
+				return m, m.op.Init()
 			case key.Matches(msg, m.keymap.Rebase.Mode):
 				m.op = rebase.NewOperation(m.context, m.SelectedRevisions(), rebase.SourceRevision, rebase.TargetDestination)
+				return m, m.op.Init()
 			case key.Matches(msg, m.keymap.Duplicate.Mode):
 				m.op = duplicate.NewOperation(m.context, m.SelectedRevisions(), duplicate.TargetDestination)
-			case key.Matches(msg, m.keymap.Megamerge):
-				m.op = megamerge.NewModel(m.context, m.SelectedRevision())
+				return m, m.op.Init()
+			case key.Matches(msg, m.keymap.SetParents):
+				m.op = set_parents.NewModel(m.context, m.SelectedRevision())
+				return m, m.op.Init()
 			}
 		}
 	}
 
-	if curSelected := m.SelectedRevision(); curSelected != nil {
-		if op, ok := m.op.(operations.TracksSelectedRevision); ok {
-			op.SetSelectedRevision(curSelected)
-		}
-		return m, tea.Batch(m.updateSelection(), cmd)
-	}
 	return m, cmd
 }
 
+func (m *Model) startSquash(selectedRevisions jj.SelectedRevisions, files []string) (*Model, tea.Cmd) {
+	parent, _ := m.context.RunCommandImmediate(jj.GetParent(selectedRevisions))
+	parentIdx := m.selectRevision(string(parent))
+	if parentIdx != -1 {
+		m.cursor = parentIdx
+	} else if m.cursor < len(m.rows)-1 {
+		m.cursor++
+	}
+	m.op = squash.NewOperation(m.context, selectedRevisions, squash.WithFiles(files))
+	return m, m.op.Init()
+}
+
 func (m *Model) updateSelection() tea.Cmd {
 	if selectedRevision := m.SelectedRevision(); selectedRevision != nil {
 		return m.context.SetSelectedItem(appContext.SelectedRevision{
@@ -435,7 +524,7 @@ func (m *Model) highlightChanges() tea.Msg {
 		if len(parts) > 0 {
 			for i := range m.rows {
 				row := &m.rows[i]
-				if row.Commit.GetChangeId() == parts[0] {
+				if strings.HasPrefix(parts[0], row.Commit.GetChangeId()) {
 					row.IsAffected = true
 					break
 				}
@@ -472,26 +561,24 @@ func (m *Model) updateGraphRows(rows []parser.Row, selectedRevision string) {
 func (m *Model) View() string {
 	if len(m.rows) == 0 {
 		if m.isLoading {
-			return lipgloss.Place(m.width, m.height, lipgloss.Center, lipgloss.Center, "loading")
+			return lipgloss.Place(m.Width, m.Height, lipgloss.Center, lipgloss.Center, "loading")
 		}
-		return lipgloss.Place(m.width, m.height, lipgloss.Center, lipgloss.Center, "(no matching revisions)")
+		return lipgloss.Place(m.Width, m.Height, lipgloss.Center, lipgloss.Center, "(no matching revisions)")
 	}
 
-	renderer := graph.NewDefaultRowIterator(m.rows, graph.WithWidth(m.width), graph.WithStylePrefix("revisions"), graph.WithSelections(m.context.GetSelectedRevisions()))
-	renderer.Op = m.op
-	renderer.Cursor = m.cursor
-	renderer.SearchText = m.quickSearch
-	renderer.AceJumpPrefix = m.aceJump.Prefix()
-
-	m.w.SetSize(m.width, m.height)
 	if config.Current.UI.Tracer.Enabled {
-		start, end := m.w.FirstRowIndex(), m.w.LastRowIndex()+1 // +1 because the last row is inclusive in the view range
+		start, end := m.renderer.FirstRowIndex, m.renderer.LastRowIndex+1 // +1 because the last row is inclusive in the view range
 		log.Println("Visible row range:", start, end, "Cursor:", m.cursor, "Total rows:", len(m.rows))
-		renderer.Tracer = parser.NewTracer(m.rows, m.cursor, start, end)
+		m.renderer.tracer = parser.NewTracer(m.rows, m.cursor, start, end)
+	} else {
+		m.renderer.tracer = parser.NewNoopTracer()
 	}
-	output := m.w.Render(renderer)
-	output = m.textStyle.MaxWidth(m.width).Render(output)
-	return lipgloss.Place(m.width, m.height, 0, 0, output)
+
+	m.renderer.selections = m.context.GetSelectedRevisions()
+
+	output := m.renderer.Render(m.cursor)
+	output = m.textStyle.MaxWidth(m.Width).Render(output)
+	return lipgloss.Place(m.Width, m.Height, 0, 0, output)
 }
 
 func (m *Model) load(revset string, selectedRevision string) tea.Cmd {
@@ -509,7 +596,7 @@ func (m *Model) load(revset string, selectedRevision string) tea.Cmd {
 }
 
 func (m *Model) loadStreaming(revset string, selectedRevision string, tag uint64) tea.Cmd {
-	if m.tag != tag {
+	if m.tag.Load() != tag {
 		return nil
 	}
 
@@ -546,8 +633,11 @@ func (m *Model) requestMoreRows(tag uint64) tea.Cmd {
 		if m.streamer == nil || !m.hasMore {
 			return nil
 		}
-		batch := m.streamer.RequestMore()
-		return appendRowsBatchMsg{batch.Rows, batch.HasMore, tag}
+		if tag == m.tag.Load() {
+			batch := m.streamer.RequestMore()
+			return appendRowsBatchMsg{batch.Rows, batch.HasMore, tag}
+		}
+		return nil
 	}
 }
 
@@ -586,7 +676,7 @@ func (m *Model) search(startIndex int) int {
 }
 
 func (m *Model) CurrentOperation() operations.Operation {
-	return m.op
+	return m.op.(operations.Operation)
 }
 
 func (m *Model) GetCommitIds() []string {
@@ -597,41 +687,22 @@ func (m *Model) GetCommitIds() []string {
 	return commitIds
 }
 
-func New(c *appContext.MainContext) Model {
+func New(c *appContext.MainContext) *Model {
 	keymap := config.Current.GetKeyMap()
-	w := graph.NewRenderer(20, 10)
-	return Model{
+	m := Model{
+		Sizeable:      &common.Sizeable{Width: 0, Height: 0},
 		context:       c,
-		w:             w,
 		keymap:        keymap,
 		rows:          nil,
 		offScreenRows: nil,
 		op:            operations.NewDefault(),
 		cursor:        0,
-		width:         20,
-		height:        10,
 		textStyle:     common.DefaultPalette.Get("revisions text"),
+		dimmedStyle:   common.DefaultPalette.Get("revisions dimmed"),
+		selectedStyle: common.DefaultPalette.Get("revisions selected"),
 	}
-}
-
-func (m *Model) updateOperation(msg tea.Msg) (tea.Cmd, bool) {
-	// HACK: Evolog operation with overlay but also change its mode from select to restore.
-	// In 'select' mode, they function like standard overlays.
-	// 'Restore' mode transforms them into rebase/squash-like operations.
-	// This is currently a hack due to the lack of a mechanism to handle mode changes.
-	// The 'restore' mode name was added to facilitate this special case.
-	// Future refactoring will address mode changes more generically.
-	if m.op != nil && (m.op.Name() == "restore" || m.op.Name() == "target") {
-		if _, ok := msg.(tea.KeyMsg); ok {
-			return nil, false
-		}
-	}
-	var cmd tea.Cmd
-	if op, ok := m.op.(operations.OperationWithOverlay); ok {
-		m.op, cmd = op.Update(msg)
-		return cmd, true
-	}
-	return nil, false
+	m.renderer = newRevisionListRenderer(&m, m.Sizeable)
+	return &m
 }
 
 func (m *Model) jumpToParent(revisions jj.SelectedRevisions) {
